Crate libcrux_ed25519

Crate libcrux_ed25519 

Structs

SigningKey
An Ed25519 private, signing key
VerificationKey
An Ed25519 public, verification key

Enums

Error

Functions

secret_to_public
Compute the public point for the given secret key sk. The hacl implementation requires that these are both 32 byte buffers, which we enforce through types.
sign
The hacl implementation requires that
verify
The hacl implementation requires that