Structs
- Signing
Key - An Ed25519 private, signing key
- Verification
Key - An Ed25519 public, verification key
Enums
Functions
- secret_
to_ public - Compute the public point for the given secret key
sk. The hacl implementation requires that these are both 32 byte buffers, which we enforce through types. - sign
- The hacl implementation requires that
- verify
- The hacl implementation requires that